
# Akhdefo: 
Computer Vision for Slope Stability: Land Deformation Monitoring Using Optical Satellite Imagery
# Background of Akh-Defo:
AKh-Defo is combination of two different words 1) Akh in Kurdish language means land, earth or soil (origion of the word is from Kurdish badini dailect) 2) Defo is short of English word deformation.

# Recommended Citation:
Muhammad M, Williams-Jones G, Stead D, Tortini R, Falorni G and Donati D (2022) Applications of ImageBased Computer Vision for Remote Surveillance of Slope Instability.Front. Earth Sci. 10:909078. doi: 10.3389/feart.2022.909078

# Updates:
* Akhdefo version one is deprecated please use Akhdefo version 2.
* Akhdefo now can run on the cloud for real-time processing
* Akhdefo now consist more than 20 Modules that performs end to end python-based GIS and Image Processing and Custumized Figure generation
*Capability to access, filter and download planet labs data using planet lab API
*Capability to Ortho-rectify satellite images.

# Installation of Akhdefo Software:

1.[download anaconda environment akhdefov2.yml file](akhdefov2.yml) 

2.[download python package  requirement  pip_req.txt file](pip_req.txt) 

3.Create new python Anaconda environment using the below command

```python
conda env create -f akhdefov2.yml

```

4.Install required python packages using below command

```python
pip install -r pip_req.txt
```

5.Now install Akhdefo using the below command

```python
pip install akhdefo-functions
```
